@@ -950,12 +950,16 @@ $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE
 # In the file for the propagation of constraints, the vertices are named for example like this:
 # $ver{1}{2}, which means: vertex 2 of zone 1.
 # $ver{1}{2}->[0] is the "x" value; $ver{1}{2}->[1] is the "y" value; $ver{1}{2}->[2] is the "z" value
-# the obstructions are named for example like this:
+# The obstructions are named for example like this:
 # $obs{1}{2}, which means: vertex 2 of zone 1.
 # $obs{1}{2}->[0] is the "x" value of the position, ...[1] the "y", ...[2] the "z";
 # $obs{1}{2}->[4] is the width, ...[5] the depth, ...[6] the height, 
 # ...[7] the "y" rotation, ...[8] the tilt, ...[9] the opacity,
 # ...[10] the name, [11] the material.
+# The nodes of the mass-flow network are named for example like this:
+# $nod[2], which means: node 2. For what $nod[2]->[0], $nod[3]->[2] etc mean, see the source code.
+# # The components of the mass-flow network are named for example like this:
+# $comp[2], which means: component 2. For what $comp[2]->[0],  $comp[4]->[5] etc mean, see the source code.
 
 
 $vals{1}{111}{vary_controls} = 
@@ -1034,233 +1038,6 @@ $vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 ## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
 ## WITH THE FOLLOWING VARIABLES: @letters AND @period_letters
 
-$vals{1}{111}{vary_net} = 
-[ 
-[
-"/nets/cell.afn", # source file
-"/nets/cell.afn", # target file
-"/opts/default_configfile_net_constraints.pl", # config file # LEAVE BLANK. SPECIFY PROPARATION OF CONSTRAINTS SEPARATELY.
-[ #BEGINNING OF  NODES. JUST THE ONES THAT HAS TO BE CHANGED HAVE TO BE LISTED HERE
-["a", # NODE LETTER  # BEGINNING OF THE FIRST NODE. THIS IS AN INTERNAL UNKNOWN NODE.
-"a", # FLUID TYPE
-"a", # BOUNDARY TYPE
-"", # HEIGHT. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-"", # VOLUME. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-],  #  END OF THE FIRST NODE
-["b", # NODE LETTER  # BEGINNING OF THE SECOND NODE. THIS IS A BOUNDARY, WIND-INDUCED NODE
-"a", # FLUID TYPE
-"e", # BOUNDARY TYPE. LETTER
-"", # HEIGHT. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-"", # SURFACE AZIMUTH ANGLE. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-"g", # SURFACE IN ZONE, LETTER. IT CAN'T BE BLANK. THE LETTER MUST BE CHECKED IN ESP-R AND WRITTEN HERE.
-[ "f" , "g" ] # PRESSURE COEFFICIENTS (LETTERS) TO APPLY. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. THE EXCEEDING ITEMS WILL NOT BE USED.
-] , # END OF THE SECOND NODE
-["c", # NODE LETTER  # BEGINNING OF THE SECOND NODE. THIS IS A BOUNDARY, WIND-INDUCED NODE
-"a", # FLUID TYPE
-"e", # BOUNDARY TYPE
-"", # HEIGHT. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-"", #  AZIMUTH ANGLE. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-"h", # SURFACE IN ZONE, LETTER. THE LETTER MUST BE CHECKED IN ESP-R AND WRITTEN HERE.
-[ "f" , "g" ] # PRESSURE COEFFICIENTS (LETTERS) TO APPLY. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. THE EXCEEDING ITEMS WILL NOT BE USED.
-]  # END OF THE THIRD NODE
-], # END OF NODES
-[ # BEGINNING OF COMPONENTS. JUST THE ONES THAT HAS TO BE CHANGED HAVE TO BE LISTED HERE
-["a", # COMPONENT LETTER  # BEGINNING OF THE FIRST COMPONENT. THIS IS A WINDOW EXAMPLE
-"k", # COMPONENT TYPE. "k" IS FOR WINDOWS, "l" FOR CRACKS, AND "m" FOR DOORS.
-.4 # SWING OF THE AREA. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE] , 
-], # END OF THE FIRST COMPONENT
-["b", # COMPONENT LETTER  # BEGINNING OF THE SECOND COMPONENT. THIS IS THE EXAMPLE OF A CRACK
-"l", # COMPONENT TYPE. "k" IS FOR WINDOWS, "l" FOR CRACKS, AND "m" FOR DOORS.
-.1,  # SWING OF THE CRACK WIDTH IN MM. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-.2 # SWING OF THE CRACK LENGTH IN M. LEAVE "" BLANK IF YOU ACCEPT THE CURRENT VALUE
-], # END OF THE SECOND COMPONENT
-["c", # COMPONENT LETTER  # BEGINNING OF THE THIRD COMPONENT. THIS IS THE EXAMPLE OF A DOOR
-"m", # COMPONENT TYPE. "k" IS FOR WINDOWS, "l" FOR CRACKS, AND "m" FOR DOORS.
-.1,  # SWING OF THE DOOR WIDTH.
-.1, # SWING OF THE DOOR HEIGHT
-.1, # SWING OF THE HEIGHT OF THE ADJOINING NODE ABOVE BASE
-0 # SWING OF THE DISCHARGE FACTOR
-], # END OF THE THIRD COMPONENT
-] # END OF NET COMPONENTS
-], # END OF DATA FOR THE FIRST SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE, ETC. NEW SEQUENCES CAN BE ADDED.
-]; # If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-## WITH THE FOLLOWING VARIABLES:
-## @node_letters AND @component_letters 
-
-$vals{1}{111}{constrain_net} = 
-[
-[
-"/nets/cell.afn", # source file
-"/nets/cell.afn", # target file
-"/opts/default_configfile_net_constraints.pl", # config file 
-[ "none", "g", "i", "h", "j" ], # SURFACE LETTERS IN ZONE FOR EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED. IT DOESN'T MATTER WHAT IT IS. 
-[ "none", "g", "k", "f", "g" ] # BASE PRESSURE COEFFICIENT LETTERS TO APPLY TO EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED.  THE EXCEEDING ITEMS WILL NOT BE USED. 
-# ALSO, THESE VALUES WILL NOT BE USED IF DIFFERENT ONES WILL BE CALCULATED THROUGH PROPAGATION OF CONSTRAINTS, DEPENDING ON THE INSTRUCTIONS IN THE CONFIG FILE
-], 
-]; 
-## THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
-## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
-## SPECIFICALLY, @nodes and @components.
-## CURRENTLY: INTERNAL UNKNOWN AIR NODES AND BOUNDARY WIND-CONCERNED NODES.
-## IT MAKES AVAILABLE VARIABLES REGARDING COMPONENTS
-## CURRENTLY: WINDOWS, CRACKS, DOORS.
-## ALSO, THIS FILE MAKES AVAILABLE TO THE USER INFORMATIONS ABOUT THE MORPHING STEP OF THE MODELS.
-## SPECIFICALLY, THE FOLLOWING VARIABLES WHICH REGARD BOTH INTERNAL AND BOUNDARY NODES.
-## NOTE THAT "node_number" IS THE NUMBER OF THE NODE IN THE ".afn" ESP-r FILE. 
-## $node[node_number][$node]. # EXAMPLE: $node[3][$node]. THIS IS THE LETTER OF THE THIRD NODE.
-## $node[node_number][$type]
-## $node[node_number][$height]. # EXAMPLE: $node[3][$height]. THIS IS THE HEIGHT OF THE 3RD NODE.
-## THEN IT MAKES AVAILABLE THE FOLLOWING VARIABLES REGARDING NODES:
-## $node[node_number][$volume] # REGARDING INTERNAL NODES
-## $node[node_number][$azimut] # REGARDING BOUNDARY NODES
-## THEN IT MAKE AVAILABLE THE FOLLOWING VARIABLES REGARDING COMPONENTS:
-## $component[node_number][$area] # REGARDING SIMPLE OPENINGS
-## $component[node_number][$width] # REGARDING CRACKS
-## $component[node_number][$length] # REGARDING CRACKS
-## $component[node_number][$door_width] # REGARDING DOORS
-## $component[node_number][$door_height] # REGARDING DOORS
-## $component[node_number][$door_nodeheight] # REGARDING DOORS
-## $component[node_number][$door_discharge] # REGARDING DOORS (DISCHARGE FACTOR)
-## ALSO, THIS FILE MAKES AVAILABLE TO THE USER INFORMATIONS ABOUT THE MORPHING STEP OF THE MODELS 
-## AND THE STEPS THE MODEL HAVE TO FOLLOW.
-## THIS ALLOWS TO IMPOSE EQUALITY CONSTRAINTS TO THESE VARIABLES, 
-## WHICH COULD ALSO BE COMBINED WITH THE FOLLOWING ONES: 
-## $stepsvar, WHICH TELLS THE PROGRAM HOW MANY ITERATION STEPS IT HAS TO DO IN THE CURRENT MORPHING PHASE.
-## $counterzone, WHICH TELLS THE PROGRAM WHAT OPERATION IS BEING EXECUTED IN THE CHAIN OF OPERATIONS 
-## THAT MAY BE EXECUTES AT EACH MORPHING PHASE. EACH $counterzone WILL CONTAIN ONE OR MORE ITERATION STEPS.
-## TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
-## THE OTHER ARE APPLIED TO THE SAME ZONE.
-## $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-## WITH THE FOLLOWING VARIABLES: @vertexletters (FOR GEOMETRY EDITING), @obs_letters (FOR OBSTRUCTIONS), 
-## @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
-
-
-$vals{1}{111}{propagate_constraints} = [ 
-[
-[ "read_geo", # what to do
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "k", "l", "m", "n" ], # vertex letters to be changed.
-"y" # ARE THERE LONG MENUS? "y" or "n".
-],
-["read_net", # what to do
-"/nets/cell.afn", # source file
-"/nets/cell.afn", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "none", "g", "i", "h", "j" ], # SURFACE LETTERS IN ZONE FOR EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED. IT DOESN'T MATTER WHAT IT IS. "none" IS FINE BECAUSE IT IS CLEAR. 
-[ "none", "g", "k", "f", "g" ] # BASE PRESSURE COEFFICIENT LETTERS TO APPLY TO EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED. IT DOESN'T MATTER WHAT IT IS. "none" IS FINE BECAUSE IT IS CLEAR. # THE EXCEEDING ITEMS WILL NOT BE USED. 
-# THE EXCEEDING ITEMS WILL NOT BE USED. ALSO, THESE VALUES WILL NOT BE USED IF DIFFERENT ONES WILL BE CALCULATED THROUGH PROPAGATION OF CONSTRAINTS, DEPENDING ON THE INSTRUCTIONS IN THE CONFIG FILE
-], 
-[ "read_obs", # what to do
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "e", "f", "g", "h"], # obstruction letters to be changed.
-"n" # act on materials too? "y" or "n". That materials letters (as they appear in the material database) and not materials names have to be given in the configuration files.
-],
-["read_ctl", # what to do
-"/ctl/cell.ctl", # source file
-"/ctl/cell.ctl", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-],
-["write_ctl", # what to do
-"/ctl/cell.ctl", # source file
-"/ctl/cell.ctl", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-],
-["write_net", # what to do
-"/nets/cell.afn", # source file
-"/nets/cell.afn", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "none", "g", "i", "h", "j" ], # SURFACE LETTERS IN ZONE FOR EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED. IT DOESN'T MATTER WHAT IT IS.
-[ "none", "g", "k", "f", "g" ] # BASE PRESSURE COEFFICIENT LETTERS TO APPLY TO EACH NETWORK NODE, IN THE SAME ORDER AS THEY APPEAR IN THE ".afn" FILE. 
-# THEY MUST BE AT LEAST THE SAME NUMBER OF $stepsvar. 
-# ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED.  THE EXCEEDING ITEMS WILL NOT BE USED. 
-# ALSO, THESE VALUES WILL NOT BE USED IF DIFFERENT ONES WILL BE CALCULATED THROUGH PROPAGATION OF CONSTRAINTS, DEPENDING ON THE INSTRUCTIONS IN THE CONFIG FILE
-], 
-[ "write_geo", # what to do
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "k", "l", "m", "n"], # vertex letters to be changed.
-"y", # ARE THERE LONG MENUS? "y" or "n".
-0 # $askop: the number of the subarray in which the data structure to be used is. It depends on the order in which it has been read, on the $countop.
-],
-[ "write_obs", # what to do
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_constraints.pl", # config file 
-[ "e", "f", "g", "h"], # obstruction letters to be changed.
-"n" # act on materials too? "y" or "n". That materials letters (as they appear in the material database) and not materials names have to be given in the configuration files.
-]
-],
-]; # THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
-## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
-## THIS FILE ALLOWS TO MANIPULATE COMPOUND USER-IMPOSED CONSTRAINTS.
-## IT MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES FOR MANIPULATION.
-## IT IS POSSIBILE TO OPERATE ON GEOMETRY, CONSTRUCTIION
-## REGARDING GEOMETRY:
-## @v[$number][$x], @v[$number][$y], @v[$number][$z]. EXAMPLE: @v[4][$x] = 1. OR: @v[4][$x] =  @v[4][$y].
-## REGARDING OBSTRUCTIONS:
-## $obs[$obs_number][$x], $obs[$obs_number][$y], $obs[$obs_number][$y]
-## $obs[$obs_number][$width], $obs[$obs_number][$depth], $obs[$obs_number][$height]
-## $obs[$obs_number][$z_rotation], $obs[$obs_number][$y_rotation], 
-## $obs[$obs_number][$tilt], $obs[$obs_number][$opacity], $obs[$obs_number][$material], 
-## EXAMPLE: $obs[2][$x] = 2. THIS MEANS: COORDINATE x OF OBSTRUCTION HAS TO BE SET TO 2.
-## OTHER EXAMPLE: $obs[2][$x] = $obs[2][$y]. THIS MEANS: 
-## NOTE THAT THE MATERIAL TO BE SPECIFIED IS A MATERIAL LETTER, BETWEEN QUOTES! EXAMPLE: $obs[1][$material] = "a".
-##  $tilt IS PRESENTLY UNUSED.
-## REGARDING MASS-FLOW NETWORKS:
-## @nodes and @components.
-## CURRENTLY: INTERNAL UNKNOWN AIR NODES AND BOUNDARY WIND-CONCERNED NODES.
-## IT MAKES AVAILABLE VARIABLES REGARDING COMPONENTS
-## CURRENTLY: WINDOWS, CRACKS, DOORS.
-## ALSO, THIS FILE MAKES AVAILABLE TO THE USER INFORMATIONS ABOUT THE MORPHING STEP OF THE MODELS.
-## SPECIFICALLY, THE FOLLOWING VARIABLES WHICH REGARD BOTH INTERNAL AND BOUNDARY NODES.
-## NOTE THAT "node_number" IS THE NUMBER OF THE NODE IN THE ".afn" ESP-r FILE. 
-## $node[node_number][$node]. # EXAMPLE: $node[3][$node]. THIS IS THE LETTER OF THE THIRD NODE.
-## $node[node_number][$type]
-## $node[node_number][$height]. # EXAMPLE: $node[3][$height]. THIS IS THE HEIGHT OF THE 3RD NODE.
-## THEN IT MAKES AVAILABLE THE FOLLOWING VARIABLES REGARDING NODES:
-## $node[node_number][$volume] # REGARDING INTERNAL NODES
-## $node[node_number][$azimut] # REGARDING BOUNDARY NODES
-## THEN IT MAKE AVAILABLE THE FOLLOWING VARIABLES REGARDING COMPONENTS:
-## $component[node_number][$area] # REGARDING SIMPLE OPENINGS
-## $component[node_number][$width] # REGARDING CRACKS
-## $component[node_number][$length] # REGARDING CRACKS
-## $component[node_number][$door_width] # REGARDING DOORS
-## $component[node_number][$door_height] # REGARDING DOORS
-## $component[node_number][$door_nodeheight] # REGARDING DOORS
-## $component[node_number][$door_discharge] # REGARDING DOORS (DISCHARGE FACTOR)
-## REGARDING CONTROLS:
-## 1) $loop_control[$countloop][$countloopcontrol][$loop_hour] 
-## Where $countloop and  $countloopcontrol has to be set to a specified number in the OPT file for constraints.
-## 2) $loop_control[$countloop][$countloopcontrol][$max_heating_power] # Same as above.
-## 3) $loop_control[$countloop][$countloopcontrol][$min_heating_power] # Same as above.
-## 4) $loop_control[$countloop][$countloopcontrol][$max_cooling_power] # Same as above.
-## 5) $loop_control[$countloop][$countloopcontrol][$min_cooling_power] # Same as above.
-## 6) $loop_control[$countloop][$countloopcontrol][heating_setpoint] # Same as above.
-## 7) $loop_control[$countloop][$countloopcontrol][cooling_setpoint] # Same as above.
-## 8) $flow_control[$countflow][$countflowcontrol][$flow_hour] 
-## Where $countflow and  $countflowcontrol has to be set to a specified number in the OPT file for constraints.
-## 9) $flow_control[$countflow][$countflowcontrol][$flow_setpoint] # Same as above.
-## 10) $flow_control[$countflow][$countflowcontrol][$flow_onoff] # Same as above.
-## 11) $flow_control[$countflow][$countflowcontrol][$flow_fraction] # Same as above.
-## EXAMPLE : $flow_control[1][2][$flow_fraction] = 0.7
-## OTHER EXAMPLE: $flow_control[1][2][$flow_fraction] = $flow_control[2][1][$flow_fraction]
-## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-## WITH THE FOLLOWING VARIABLES: @vertexletters (FOR GEOMETRY EDITING), @obs_letters (FOR OBSTRUCTIONS), 
-## @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
-## FINALLY, ALL THE VARIABLES SPECIFIED IN THIS FILE CAN BE ACCESSED. FOR EXAMPLE: $recalculateish1, $translate2, ETC.
-## THE VARIABLE AT THE CURRENT SEARCH STEP CAN BE NAMED WITHOUT THE NUMBER. EXAMPLE: $recalculateish, $translate, ETC.
-
 
 $vals{1}{111}{recalculateish} = [ [ "n" ] ];
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
@@ -1469,7 +1246,6 @@ $vals{1}{5}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 
 
 #############################################################################################
-################################## TO BE DONE. ##############################################
 #
 ##@caseseed =
 ##( 
